@@ -297,7 +297,7 @@ class Payment(BaseModel):
     payment: PaymentData
     links: Links
     payer: Payer
-    debtor: Debtor
+    debtor: Optional[Debtor]
     locale: str = None
     event_id: UUID
     event_version: str
@@ -312,7 +312,7 @@ class Payment(BaseModel):
     updated_at_must_be_iso8601 = validator('updated_at', allow_reuse=True)(check_iso_format)
 
     @validator('event_version')
-    def event_version_must_be_three(cls, v):
+    def event_version_must_be_two(cls, v):
         if float(v) != 2.0:
             raise ValidationError('event must have 2.0 as version')
         return v.title()
