@@ -23,10 +23,12 @@ class ApplicationTestCase(TestCase):
         payment_data_v2 = APaymentData(**get_application_payment_data(split=get_split_data_invalid()))
         application_v2 = Application(**get_application_data(payment_data=payment_data_v2))
         payment_data_empty_split = APaymentData(**get_application_payment_data(split=[]))
+        payment_data_empty_stamps = APaymentData(**get_application_payment_data(stamps=[]))
         applicant_minimal_data = Applicant(**get_application_minimal_applicant_data())
         self.assertEqual(application.id, UUID('3c819c1d-6587-448d-8ba4-3b6f23e87ed4'))
         self.assertEqual(application_v2.payment_data.split, {'c_1': 14.0, 'c_2': None})
         self.assertEqual(payment_data_empty_split.split, [])
+        self.assertEqual(payment_data_empty_stamps.stamps, [])
         with self.assertRaises(ValidationError):
             APaymentData(
                 **get_application_payment_data(
